@@ -11,7 +11,7 @@
 
 package Wx::Perl::ProcessStream;
 
-our $VERSION = '0.27';
+our $VERSION = '0.29';
 
 =head1 NAME
 
@@ -19,7 +19,7 @@ Wx::Perl::ProcessStream - access IO of external processes via events
 
 =head1 VERSION
 
-Version 0.27
+Version 0.29
 
 =head1 SYNOPSYS
 
@@ -469,7 +469,7 @@ if( Wx::wxVERSION() < 2.0060025) {
 #-----------------------------------------------------
 
 our ($ID_CMD_EXIT, $ID_CMD_STDOUT, $ID_CMD_STDERR, $ID_CMD_MAXLINES,
-     $WXP_DEFAULT_CLOSE_ACTION, $WXP_DEFAULT_MAX_LINES, $WXPDEBUG, $WX_YIELD_EXTENDED);
+     $WXP_DEFAULT_CLOSE_ACTION, $WXP_DEFAULT_MAX_LINES, $WXPDEBUG);
 
 $ID_CMD_EXIT   = Wx::NewEventType();
 $ID_CMD_STDOUT = Wx::NewEventType();
@@ -511,17 +511,18 @@ sub EVT_WXP_PROCESS_STREAM_EXIT     ($$) { $_[0]->Connect(-1,-1,&wxpEVT_PROCESS_
 sub EVT_WXP_PROCESS_STREAM_MAXLINES ($$) { $_[0]->Connect(-1,-1,&wxpEVT_PROCESS_STREAM_MAXLINES,   $_[1] ) };
 
 sub Yield {
-    if(defined($WX_YIELD_EXTENDED)) {
-        ($WX_YIELD_EXTENDED) ? Wx::wxTheApp->Yield(1) : Wx::wxTheApp->Yield();
-    } else {
-        eval { Wx::TheApp->Yield(1); };
-        if($@) {
-            $WX_YIELD_EXTENDED = 0;
-            Wx::wxTheApp->Yield();
-        } else {
-            $WX_YIELD_EXTENDED = 1;
-        }
-    }
+    #if(defined($WX_YIELD_EXTENDED)) {
+    #    ($WX_YIELD_EXTENDED) ? Wx::wxTheApp->Yield(1) : Wx::wxTheApp->Yield();
+    #} else {
+    #    eval { Wx::TheApp->Yield(1); };
+    #    if($@) {
+    #        $WX_YIELD_EXTENDED = 0;
+    #        Wx::wxTheApp->Yield();
+    #    } else {
+    #        $WX_YIELD_EXTENDED = 1;
+    #    }
+    #}
+    Wx::YieldIfNeeded;
 }
 
 # Old interface - call Wx::Perl::ProcessStream::new
